--- layout: default title: Extensions - Simditor id: extension ---

Simditor only integrates key features and uses extensions to support some optional features.
Send your repository to us! We are happy to receive your extensions!

Please make your extension has the similar structure as the official ones.
We will update the list below when received a new extension.

### Official Extensions

- simditor-emoji: emoji
- simditor-mention: public reply ('@')
- simditor-autosave: auto saving feature
- simditor-mark: marker pen
- simditor-html: HTML source code editing
- simditor-markdown: markdown editing
- simditor-checklist: checklist feature

### Third-party Extensions

- simditor-marked: formating markdown in textarea
- simditor-dropzone: drag and drop images to upload
- simditor-fullscreen: full screen the editor

Submit Extension